# hoppy (High-energy Observatory Pipelines of PYthon)
This package includes libararies and scripts for X-ray analyses of High-energy Observatory Pipelines of PYthon (HOPPY). 

## Structure

```
hoppy
├── LICENSE
├── MANIFEST.in
├── README.md
├── dist
├── hoppy
│   ├── general
│   │   └── __init__.py
│   ├── nicer
│   │   └── __init__.py
│   ├── plot
│   │   └── __init__.py
│   └── swift
│       └── __init__.py
└── setup.py
```

## Reference
- Python package lesson https://github.com/BillMills/pythonPackageLesson (see demo python package)
- PEP 8 -- Style Guide for Python Code https://www.python.org/dev/peps/pep-0008/?
